#!/usr/bin/env python3
# -*- coding: utf-8 -*-
'''
This module conatins functions and objects for
handling (mostly reading) less popular or vendor-specific
data file formats used in meterology and neighboring
sciences.
'''

__all__ = ['akterm', 'dmna', 'scintec1', 'toa5',
           '__title__', '__description__', '__version__',
           '__url__', '__author__', '__author_email__',
           '__license__', '__copyright__']

from . import akterm
from . import dmna
from . import scintec1
from . import toa5

from ._version import __title__, __description__, __version__
from ._version import __url__, __author__, __author_email__
from ._version import __license__, __copyright__



#!/usr/bin/env python3

import os
from setuptools import setup

v = {}
v_path = os.path.join(*'readmet/_version.py'.split('/'))
with open(v_path) as v_file:
    exec(v_file.read(), v)


setup(
    name=v['__title__'],
    version=v['__version__'],
    packages=[v['__title__']],
    package_dir={v['__title__']: v['__title__']},
    author=v['__author__'],
    author_email=v['__author_email__'],
    url=v['__url__'],
    install_requires=[
        'numpy',
        'pandas',
    ],
    license = v['__license__'],
    description = v['__description__'],
    long_description = open('README.md').read(),
    long_description_content_type='text/markdown',
)

